####
popbill.py
####
popbill 1.0.2

팝빌 API for Python.

.. image:: https://api.travis-ci.org/linkhub-sdk/popbill.py.svg?branch=master
        :target: https://travis-ci.org/linkhub-sdk/popbill.py

.. image:: https://pypip.in/d/popbill/badge.svg
        :target: https://pypi.python.org/pypi/popbill

* requirements
 
  * Python 2.6+
  * linkhub

************
Installation
************

Install via pip:

::

    $ pip install popbill

Install from source:

::

    $ git clone git://github.com/linkhub-sdk/popbill.py.git
    $ cd popbill.py
    $ python setup.py install
